@@ -145,7 +145,9 @@ class Promises(LibraryComponent):
 
     @keyword(tags=("Setter", "PageContent"))
     def promise_to_upload_file(self, path: PathLike):
-        """Returns a promise that resolves when file from ``path`` has been uploaded.
+        """*!!DEPRECATED!!* Use keyword `Upload File By Selector` instead if possible. If your use case _needs_ promise to upload file please let the Browser team know by creating an issue.
+
+        Returns a promise that resolves when file from ``path`` has been uploaded.
 
         Fails if the upload has not happened during timeout.
 
@@ -153,6 +155,8 @@ class Promises(LibraryComponent):
 
         ``path`` Path to file to be uploaded.
 
+        !! Due to a certain problem with Playwright library currently files over 74 MB will fail to upload. !!
+
         Example use:
 
         | ${promise}=    `Promise To Upload File`    ${CURDIR}/test_upload_file
